==> jc-1.4.0.tar.gz: soot/RefLikeType.c <==
// public abstract class soot.RefLikeType

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class b6d33af8f84fdbc4 soot_G
// @dep_class fdbc627922b0ba72 soot_RefLikeType
// @dep_class 7120c8047949f8c0 soot_Scene
// @dep_class 6ac5bee50bbabb71 soot_Singletons
// @dep_class f801e5c664424a1 soot_Type
// @dep_class 121e4167530beabb soot_util_Numberable
// @dep_class f5f751433138bc27 soot_util_Numberer
// @dep_class f02c62287b0e68ad soot_util_Switchable

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_G
// @dep_header soot_RefLikeType
// @dep_header soot_Scene
// @dep_header soot_util_Numberable
// @dep_header soot_util_Numberer
// @dep_header soot_util_Switchable

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/G.h"
#include "soot/RefLikeType.h"
#include "soot/Scene.h"
#include "soot/util/Numberable.h"
#include "soot/util/Numberer.h"
#include "soot/util/Switchable.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_RefLikeType$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_RefLikeType$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_RefLikeType$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_RefLikeType$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_RefLikeType$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_RefLikeType$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_RefLikeType$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_RefLikeType, _init$52f4ad9f2989aeee);

void
_jc_soot_RefLikeType$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_RefLikeType$object *this)
{
	struct _jc_soot_RefLikeType$object *r0;
	struct _jc_soot_util_Numberer$object *r1;
	struct _jc_soot_Scene$object *r3;
	struct _jc_soot_G$object *r4;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_PRIM_FIELD(env, r0, soot_Type, number) = 0;
	_JC_ACTIVE_USE(env, soot_Scene);
	_JC_ACTIVE_USE(env, soot_G);
	r4 = _JC_STATIC_FIELD(env, soot_G, instance, 1);
	r3 = _JC_INVOKE_VIRTUAL(env, soot_Singletons, Scene$3451207662ac1af0, r4);
	r1 = _JC_INVOKE_VIRTUAL(env, soot_Scene, getTypeNumberer$1a245dd462a8adec, r3);
	_JC_INVOKE_VIRTUAL(env, soot_util_Numberer, add$5470e142c10db8b0, r1, r0);
	_JC_LINE_NUMBER(31);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract soot.Type getArrayElementType()
//

static const unsigned char _jc_soot_RefLikeType$param_ptypes$getArrayElementType$15d4b254b1d62067[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_RefLikeType$method_info$getArrayElementType$15d4b254b1d62067 = {
	.name=			"getArrayElementType",
	.signature=		"()Lsoot/Type;",
	.class=			&_jc_soot_RefLikeType$type,
	.return_type=		&_jc_soot_Type$type,
	.param_ptypes=		&_jc_soot_RefLikeType$param_ptypes$getArrayElementType$15d4b254b1d62067,
	.signature_hash=	_JC_JLONG(0x15d4b254b1d62067),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_soot_RefLikeType$method$getArrayElementType$15d4b254b1d62067,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_RefLikeType$vtable, soot_RefLikeType.getArrayElementType$15d4b254b1d62067) / sizeof(void *),
	.num_parameters=	0,
};

_jc_soot_Type$object *
_jc_soot_RefLikeType$method$getArrayElementType$15d4b254b1d62067(_jc_env *const env, _jc_soot_RefLikeType$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_soot_RefLikeType$method_info$getArrayElementType$15d4b254b1d62067);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_RefLikeType$methods[] = {
	&_jc_soot_RefLikeType$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_RefLikeType$method_info$getArrayElementType$15d4b254b1d62067
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_RefLikeType$instanceof_hash_bucket_33[] = {
	&_jc_soot_Type$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_RefLikeType$instanceof_hash_bucket_45[] = {
	&_jc_soot_util_Switchable$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_RefLikeType$instanceof_hash_bucket_59[] = {
	&_jc_soot_util_Numberable$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_RefLikeType$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_RefLikeType$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_RefLikeType$instanceof_hash_bucket_114[] = {
	&_jc_soot_RefLikeType$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_RefLikeType$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[33]=	_jc_soot_RefLikeType$instanceof_hash_bucket_33,
	[45]=	_jc_soot_RefLikeType$instanceof_hash_bucket_45,
	[59]=	_jc_soot_RefLikeType$instanceof_hash_bucket_59,
	[65]=	_jc_soot_RefLikeType$instanceof_hash_bucket_65,
	[113]=	_jc_soot_RefLikeType$instanceof_hash_bucket_113,
	[114]=	_jc_soot_RefLikeType$instanceof_hash_bucket_114
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_RefLikeType$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "soot/G",	_JC_JLONG(0xb6d33af8f84fdbc4) },
	{ "soot/Scene",	_JC_JLONG(0x7120c8047949f8c0) },
	{ "soot/Singletons",	_JC_JLONG(0x6ac5bee50bbabb71) },
	{ "soot/Type",	_JC_JLONG(0xf801e5c664424a1) },
	{ "soot/util/Numberable",	_JC_JLONG(0x121e4167530beabb) },
	{ "soot/util/Numberer",	_JC_JLONG(0xf5f751433138bc27) },
	{ "soot/util/Switchable",	_JC_JLONG(0xf02c62287b0e68ad) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_RefLikeType$vtype _jc_soot_RefLikeType$type = {
    .type= {
	.name=			"soot/RefLikeType",
	.superclass=		&_jc_soot_Type$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		20,
		.hash=			_JC_JLONG(0xfdbc627922b0ba72),
		.source_file=		"RefLikeType.java",
		.instance_size=		sizeof(_jc_soot_RefLikeType$refs) + sizeof(_jc_soot_RefLikeType$object),
		.num_virtual_refs=	1,
		.num_methods=		sizeof(_jc_soot_RefLikeType$methods) / sizeof(*_jc_soot_RefLikeType$methods),
		.methods=		_jc_soot_RefLikeType$methods,
		.instanceof_hash_table=	_jc_soot_RefLikeType$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_RefLikeType$class_depends) / sizeof(*_jc_soot_RefLikeType$class_depends),
		.class_depends=		_jc_soot_RefLikeType$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_soot_Type$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_Type= {
	    .apply$cd67f53165014a6d=
		&_jc_soot_Type$method$apply$cd67f53165014a6d,
	    .getArrayType$4b65c22ff74f3837=
		&_jc_soot_Type$method$getArrayType$4b65c22ff74f3837,
	    .getNumber$9f4729baae2d2787=
		&_jc_soot_Type$method$getNumber$9f4729baae2d2787,
	    .makeArrayType$7e244a97733ffd20=
		&_jc_soot_Type$method$makeArrayType$7e244a97733ffd20,
	    .merge$1d3370a62fb82894=
		&_jc_soot_Type$method$merge$1d3370a62fb82894,
	    .setArrayType$39da61b141afddaa=
		&_jc_soot_Type$method$setArrayType$39da61b141afddaa,
	    .setNumber$72e40df050255abc=
		&_jc_soot_Type$method$setNumber$72e40df050255abc,
	    .toString$7ea43b33b80a3070=
		&_jc_soot_Type$method$toString$7ea43b33b80a3070,
	},
	.soot_RefLikeType= {
	    .getArrayElementType$15d4b254b1d62067=
		&_jc_soot_RefLikeType$method$getArrayElementType$15d4b254b1d62067,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/RefLikeType.c <==
// public abstract class soot.RefLikeType

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class b6d33af8f84fdbc4 soot_G
// @dep_class fdbc627922b0ba72 soot_RefLikeType
// @dep_class 7120c8047949f8c0 soot_Scene
// @dep_class 6ac5bee50bbabb71 soot_Singletons
// @dep_class f801e5c664424a1 soot_Type
// @dep_class 121e4167530beabb soot_util_Numberable
// @dep_class f5f751433138bc27 soot_util_Numberer
// @dep_class f02c62287b0e68ad soot_util_Switchable

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_G
// @dep_header soot_RefLikeType
// @dep_header soot_Scene
// @dep_header soot_util_Numberable
// @dep_header soot_util_Numberer
// @dep_header soot_util_Switchable

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/G.h"
#include "soot/RefLikeType.h"
#include "soot/Scene.h"
#include "soot/util/Numberable.h"
#include "soot/util/Numberer.h"
#include "soot/util/Switchable.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_soot_RefLikeType$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_RefLikeType$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_RefLikeType$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_RefLikeType$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_RefLikeType$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_RefLikeType$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_RefLikeType$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_RefLikeType, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_RefLikeType$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_RefLikeType$object *this)
{
	struct _jc_soot_RefLikeType$object *r0;
	struct _jc_soot_util_Numberer$object *r1;
	struct _jc_soot_Scene$object *r3;
	struct _jc_soot_G$object *r4;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_PRIM_FIELD(env, r0, soot_Type, number) = 0;
	_JC_ACTIVE_USE(env, soot_Scene);
	_JC_ACTIVE_USE(env, soot_G);
	r4 = _JC_STATIC_FIELD(env, soot_G, instance, 1);
	r3 = _JC_INVOKE_VIRTUAL(env, soot_Singletons, Scene$3451207662ac1af0, r4);
	r1 = _JC_INVOKE_VIRTUAL(env, soot_Scene, getTypeNumberer$1a245dd462a8adec, r3);
	_JC_INVOKE_VIRTUAL(env, soot_util_Numberer, add$5470e142c10db8b0, r1, r0);
	_JC_LINE_NUMBER(31);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract soot.Type getArrayElementType()
//

static const unsigned char _jc_soot_RefLikeType$param_ptypes$getArrayElementType$15d4b254b1d62067[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_RefLikeType$method_info$getArrayElementType$15d4b254b1d62067 = {
	.name=			"getArrayElementType",
	.signature=		"()Lsoot/Type;",
	.class=			&_jc_soot_RefLikeType$type,
	.return_type=		&_jc_soot_Type$type,
	.param_ptypes=		&_jc_soot_RefLikeType$param_ptypes$getArrayElementType$15d4b254b1d62067,
	.signature_hash=	_JC_JLONG(0x15d4b254b1d62067),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_soot_RefLikeType$method$getArrayElementType$15d4b254b1d62067,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_RefLikeType$vtable, soot_RefLikeType.getArrayElementType$15d4b254b1d62067) / sizeof(void *),
	.num_parameters=	0,
};

_jc_soot_Type$object * _JC_JCNI_ATTR
_jc_soot_RefLikeType$method$getArrayElementType$15d4b254b1d62067(_jc_env *const env, _jc_soot_RefLikeType$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_soot_RefLikeType$method_info$getArrayElementType$15d4b254b1d62067);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_RefLikeType$methods[] = {
	&_jc_soot_RefLikeType$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_RefLikeType$method_info$getArrayElementType$15d4b254b1d62067
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_RefLikeType$instanceof_hash_bucket_33[] = {
	&_jc_soot_Type$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_RefLikeType$instanceof_hash_bucket_45[] = {
	&_jc_soot_util_Switchable$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_RefLikeType$instanceof_hash_bucket_59[] = {
	&_jc_soot_util_Numberable$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_RefLikeType$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_RefLikeType$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_RefLikeType$instanceof_hash_bucket_114[] = {
	&_jc_soot_RefLikeType$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_RefLikeType$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[33]=	_jc_soot_RefLikeType$instanceof_hash_bucket_33,
	[45]=	_jc_soot_RefLikeType$instanceof_hash_bucket_45,
	[59]=	_jc_soot_RefLikeType$instanceof_hash_bucket_59,
	[65]=	_jc_soot_RefLikeType$instanceof_hash_bucket_65,
	[101]=	_jc_soot_RefLikeType$instanceof_hash_bucket_101,
	[114]=	_jc_soot_RefLikeType$instanceof_hash_bucket_114
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_RefLikeType$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "soot/G",	_JC_JLONG(0xb6d33af8f84fdbc4) },
	{ "soot/Scene",	_JC_JLONG(0x7120c8047949f8c0) },
	{ "soot/Singletons",	_JC_JLONG(0x6ac5bee50bbabb71) },
	{ "soot/Type",	_JC_JLONG(0xf801e5c664424a1) },
	{ "soot/util/Numberable",	_JC_JLONG(0x121e4167530beabb) },
	{ "soot/util/Numberer",	_JC_JLONG(0xf5f751433138bc27) },
	{ "soot/util/Switchable",	_JC_JLONG(0xf02c62287b0e68ad) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_RefLikeType$vtype _jc_soot_RefLikeType$type = {
    .type= {
	.name=			"soot/RefLikeType",
	.superclass=		&_jc_soot_Type$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		20,
		.hash=			_JC_JLONG(0xfdbc627922b0ba72),
		.source_file=		"RefLikeType.java",
		.instance_size=		sizeof(_jc_soot_RefLikeType$refs) + sizeof(_jc_soot_RefLikeType$object),
		.num_virtual_refs=	1,
		.num_methods=		sizeof(_jc_soot_RefLikeType$methods) / sizeof(*_jc_soot_RefLikeType$methods),
		.methods=		_jc_soot_RefLikeType$methods,
		.instanceof_hash_table=	_jc_soot_RefLikeType$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_RefLikeType$class_depends) / sizeof(*_jc_soot_RefLikeType$class_depends),
		.class_depends=		_jc_soot_RefLikeType$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_soot_Type$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_Type= {
	    .apply$cd67f53165014a6d=
		&_jc_soot_Type$method$apply$cd67f53165014a6d,
	    .getArrayType$4b65c22ff74f3837=
		&_jc_soot_Type$method$getArrayType$4b65c22ff74f3837,
	    .getNumber$9f4729baae2d2787=
		&_jc_soot_Type$method$getNumber$9f4729baae2d2787,
	    .makeArrayType$7e244a97733ffd20=
		&_jc_soot_Type$method$makeArrayType$7e244a97733ffd20,
	    .merge$1d3370a62fb82894=
		&_jc_soot_Type$method$merge$1d3370a62fb82894,
	    .setArrayType$39da61b141afddaa=
		&_jc_soot_Type$method$setArrayType$39da61b141afddaa,
	    .setNumber$72e40df050255abc=
		&_jc_soot_Type$method$setNumber$72e40df050255abc,
	    .toString$7ea43b33b80a3070=
		&_jc_soot_Type$method$toString$7ea43b33b80a3070,
	},
	.soot_RefLikeType= {
	    .getArrayElementType$15d4b254b1d62067=
		&_jc_soot_RefLikeType$method$getArrayElementType$15d4b254b1d62067,
	},
    }
};
